Date: 2022-08-08
Tag: 1.10.14

## Overview

1.10.14 is the next stable release in the [long-term support (LTS)
version][release_policy][release_policy] 1.10.x release series.

The label "stable" means there are 1.10.x-based applications running in
production for quite a while without known crashes, incorrect results or
other showstopper bugs.

This release introduces 10 improvements and resolves roughly 20
issues since the 1.10.13 version.

[release_policy]: https://www.tarantool.io/en/doc/1.10/dev_guide/release_management/#release-policy
[issues]: https://github.com/tarantool/tarantool/issues

## Compatibility

Tarantool 1.10.x is backward compatible with Tarantool 1.9.x in binary data
layout, client-server protocol and replication protocol.

Please [upgrade][upgrade] using the `box.schema.upgrade()` procedure to unlock
all the new features of the 1.10.x series.

[upgrade]: https://www.tarantool.io/en/doc/1.10/book/admin/upgrades/

## Functionality added or changed

### Build

* Support fedora-35 build. (gh-6692)
* Bump OpenSSL from 1.1.1f to 1.1.1n for static build (gh-6947).
* Updated libcurl to version 7.83.0 (gh-6029).
* Support Fedora-36 build.
* Support Ubuntu Jammy (22.04) build.
* Stop support of Fedora 30/31/32/33 builds.
* Stop support of Ubuntu Hirsute (21.04) build.
* Updated libcurl to version 7.84.0.
* Bump OpenSSL from 1.1.1n to 1.1.1q for static build.
* Updated libyaml to version with fixed stack overflows.

## Bugs fixed

### Core

* Fixed memory leak in interactive console (gh-6817).
* Fixed an assertion fail when passing tuple without primary key fields
  to before_replace trigger. Now tuple format is checked before execution 
  of before_replace triggers and after each one (gh-6780).
* Now inserting a tuple with the wrong "id" field into the \_priv space will
  return the correct error (gh-6295).
* Fixed a bug due to which all fibers created with `fiber_attr_setstacksize()`
  leaked until the thread exit. Their stacks also leaked except when
  `fiber_set_joinable(..., true)` was used.
* Fixed a crash when tarantool is launched with multiple -e or -l options
  without a space between the option and the value (gh-5747).
* Fixed usage of `box.session.peer()` in `box.session.on_disconnect()` trigger.
  Now, it's safe to assume that `box.session.peer()` returns the address of the
  disconnected peer, not nil, as it used to (gh-7014).
* Fixed a bug in the sequence cache that could result in an error creating
  a new sequence (gh-5306).

### Vinyl

* Immediate removal of compacted run files created after the last checkpoint
  optimization now works for replica's initial JOIN stage (gh-6568).
* Fixed crash during recovery of a secondary index in case the primary index
  contains incompatible phantom tuples (gh-6778).
* Fixed a bug in Vinyl upsert squashing optimization that could lead to
  a segmentation fault error (gh-5080).
* Fixed a bug in Vinyl read iterator that could result in a significant
  performance degradation of range select requests in presence of an intensive
  write workload (gh-5700).

### Replication

* Fixed replicas failing to bootstrap when master is just re-started (gh-6966).

### LuaJIT

* Fixed top part of Lua stack (red zone, free slots, top slot) unwinding in
  `lj-stack` command.
* Added the value of `g->gc.mmudata` field to `lj-gc` output.
* `string.char()` builtin recording is fixed in case when no arguments are
  given (gh-6371, gh-6548).
* Actually made JIT respect `maxirconst` trace limit while recording (gh-6548).
Backported patches from vanilla LuaJIT trunk (gh-6548). In the scope of this
activity, the following issues have been resolved:

* Fixed emitting for fuse load of constant in GC64 mode (gh-4095, gh-4199, gh-4614).
* Now initialization of zero-filled struct is compiled (gh-4630, gh-5885).
* Actually implemented `maxirconst` option for tuning JIT compiler.
* Fixed JIT stack of Lua slots overflow during recording for metamethod calls.
* Fixed bytecode dump unpatching for JLOOP in up-recursion compiled functions.
* Fixed FOLD rule for strength reduction of widening in cdata indexing.
* Fixed `string.char()` recording without arguments.
* Fixed `print()` behaviour with the reloaded default metatable for numbers.
* `tonumber("-0")` now saves the sign of number for conversion.
* `tonumber()` now give predictable results for negative non-base-10 numbers.
* Fixed write barrier for `debug.setupvalue()` and `lua_setupvalue()`.
* `jit.p` now flushes and closes output file after run, not at program exit.
* Fixed `jit.p` profiler interaction with GC finalizers.
* Fixed the case for partial recording of vararg function body with the fixed
  number of result values in with `LJ_GC64` (i.e. `LJ_FR2` enabled) (gh-7172).
Backported patches from vanilla LuaJIT trunk (gh-7230). In the scope of this
activity, the following issues have been resolved:

* Fix handling of errors during trace snapshot restore.

### Box

* Add iterator type checking and allow to pass iterator as a box.index.{ALL,GT,...} directly (gh-6501).

### Recovery

* When `force_recovery` cfg option is set, Tarantool is able to boot from
  `snap`/`xlog` combinations where `xlog` covers changes committed both before
  and after `snap` creation. For example, `0...0.xlog`, covering everything up
  to vclock `{1: 15}` and `0...09.snap`, corresponding to `vclock `{1: 9}` (gh-6794).
